@@ -1,7 +1,4 @@
-#![allow(dead_code)]
 use narcissistic::narcissistic_numbers;
-use num::BigUint;
-use std::str::FromStr;
 
 #[test]
 fn narcissistic_base10() {
